@@ -132,15 +132,15 @@ class CortxJupyter(ContentsManager):
             return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
 
     def _config(self):
-        cortx_auths = yield self.authentication.get_credentials()
-        creds = {'region_name':self.region_name,'bucket_name':self.bucket_name,
-        "host_name":self.host_name,"cortx_authenticator":cortx_auths._asdict(),
-        "prefix": self.prefix,"endpoint_url":self.endpoint_url
-        }
+        # cortx_auths = yield self.authentication.get_credentials()
+        # creds = {'region_name':self.region_name,'bucket_name':self.bucket_name,
+        # "host_name":self.host_name,"cortx_authenticator":cortx_auths._asdict(),
+        # "prefix": self.prefix,"endpoint_url":self.endpoint_url
+        # }
         
-        print(creds)
-        with open(".credentials", "w") as fp:
-            json.dump(creds , fp)
+        # print(creds)
+        # with open(".credentials", "w") as fp:
+        #     json.dump(creds , fp)
 
         return Config(
             region=self.region_name,
